@@ -1,6 +1,6 @@
 class Reddit:
     def __init__(self, content, title, upvote_ratio,
-                 total_awards, score, downvotes, created_at, nsfw, pinned):
+                 total_awards, score, downvotes, created_at, nsfw, pinned, author, post_url, stickied, spoiler):
         self.content = content
         self.title = title
         self.upvote_ratio = upvote_ratio
@@ -10,3 +10,7 @@ class Reddit:
         self.created_at = created_at
         self.nsfw = nsfw
         self.pinned = pinned
+        self.author = author
+        self.post_url = post_url
+        self.stickied = stickied
+        self.spoiler = spoiler
