@@ -40,7 +40,10 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -53,8 +56,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -62,7 +80,11 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/hot.json", headers=headers,
@@ -75,7 +97,11 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -88,8 +114,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -97,7 +138,11 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
 
     def get_top_post(self):
@@ -117,7 +162,10 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -130,8 +178,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -139,7 +202,11 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/top.json", headers=headers,
@@ -152,7 +219,10 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -165,8 +235,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -174,7 +259,11 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
 
     def get_new_post(self):
@@ -193,7 +282,10 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -206,8 +298,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -215,7 +322,11 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/new.json", headers=headers,
@@ -228,7 +339,10 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -241,8 +355,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -250,7 +379,11 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
 
     def get_controversial_post(self):
@@ -269,7 +402,10 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -282,8 +418,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -291,7 +442,11 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/controversial.json", headers=headers,
@@ -304,7 +459,10 @@ class Subreddit:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -317,8 +475,23 @@ class Subreddit:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -326,5 +499,9 @@ class Subreddit:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
