@@ -28,6 +28,9 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
@@ -41,8 +44,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -50,7 +68,11 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/hot.json", headers=headers, auth=client_auth)
@@ -62,6 +84,9 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
@@ -75,8 +100,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -84,7 +124,11 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
 
     def get_top_post(self):
@@ -103,6 +147,9 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
@@ -116,8 +163,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -125,7 +187,11 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/top.json", headers=headers, auth=client_auth)
@@ -137,6 +203,9 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
@@ -150,8 +219,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -159,7 +243,11 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
 
     def get_new_post(self):
@@ -177,6 +265,9 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
@@ -190,8 +281,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -199,7 +305,11 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/new.json", headers=headers, auth=client_auth)
@@ -211,6 +321,9 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
@@ -224,8 +337,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -233,7 +361,11 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
 
     def get_controversial_post(self):
@@ -252,7 +384,10 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -265,8 +400,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -274,7 +424,11 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/controversial.json", headers=headers,
@@ -287,7 +441,10 @@ class User:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
+            stickied = meme["data"]["children"][randompost]["data"]["stickied"]
+            spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             s = meme["data"]["children"][randompost]["data"]["created"]
+            media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -300,8 +457,23 @@ class User:
             elif pinned == "false":
                 pinned = False
 
+            if stickied == "true":
+                stickied = True
+            elif stickied == "false":
+                stickied = False
+
+            if spoiler == "true":
+                spoiler = True
+            elif spoiler == "false":
+                spoiler = False
+
+            if media is None:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            else:
+                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+
             return Reddit(
-                content=meme["data"]["children"][randompost]["data"]["selftext"],
+                content=contenttext,
                 title=meme["data"]["children"][randompost]["data"]["title"],
                 upvote_ratio=meme["data"]["children"][randompost]["data"]["upvote_ratio"],
                 total_awards=meme["data"]["children"][randompost]["data"]["total_awards_received"],
@@ -309,5 +481,9 @@ class User:
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
                 pinned=pinned,
-                created_at=updated
+                created_at=updated,
+                author=meme["data"]["children"][randompost]["data"]["author"],
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                stickied=stickied,
+                spoiler=spoiler
             )
